using Autofac;
using FitConnect;
using FitConnect.Interfaces;
using FitConnect.Interfaces.Subscriber;
using Microsoft.Extensions.Logging;
using MockContainer;

namespace E2ETest;

public abstract class EndToEndTestBase {
    protected ILogger Logger = null!;
    protected ISender Sender = null!;
    protected IFitConnectSettings Settings = null!;
    protected ISubscriber Subscriber = null!;

    protected const string JSON_SCHEMA_URI =
        "https://git.fitko.de/fit-connect/sdk-dotnet/-/raw/issue/872-check-submission-data-schema/Examples/example.schema.json";

    protected const string XML_SCHEMA_URI =
        "https://git.fitko.de/fit-connect/sdk-dotnet/-/raw/issue/872-check-submission-data-schema/Examples/schema.xsd";

    protected const string JSON_DATA = @"{
""name"":""John Doe"", 
""age"":42,
""email"":""mail@mail.com""
}";

    [SetUp]
    public void Setup() {
        var container = Container.Create();
        Settings = container.Resolve<IFitConnectSettings>();

        Logger = LoggerFactory.Create(
            builder => {
                builder.AddConsole();
                builder.SetMinimumLevel(LogLevel.Warning);
            }).CreateLogger("E2E Test");


        Sender = ClientFactory.GetSenderClient(FitConnectEnvironment.Testing,
            Settings.SenderClientId, Settings.SenderClientSecret,
            Logger);
        Subscriber = ClientFactory.GetSubscriberClient(FitConnectEnvironment.Testing,
            Settings.SubscriberClientId, Settings.SubscriberClientSecret,
            Settings.PrivateDecryptionKeys,
            Settings.PrivateSigningKey,
            Logger
        );
    }
}
